@@ -5,7 +5,7 @@
 #
 # Sword module download manager program
 #
-# Copyright (C) 2016-2018 Robert Hunt
+# Copyright (C) 2016-2020 Robert Hunt
 # Author: Robert Hunt <Freely.Given.org+Biblelator@gmail.com>
 # License: See gpl-3.0.txt
 #
@@ -29,31 +29,35 @@ Tabbed dialog box to allow viewing of various BOS (Bible Organisational System)
 This is opened as a TopLevel window in Biblelator
     but can also be run as a stand-alone program.
 """
-
 from gettext import gettext as _
-
-LAST_MODIFIED_DATE = '2018-12-12' # by RJH
-SHORT_PROGRAM_NAME = "SwordManager"
-PROGRAM_NAME = "Sword Manager"
-PROGRAM_VERSION = '0.05' # Separate versioning from Biblelator
-programNameVersion = f'{SHORT_PROGRAM_NAME} v{PROGRAM_VERSION}'
-
-debuggingThisModule = True
-
-
 import sys
 import os
-import logging, subprocess
+import logging
+import subprocess
 import multiprocessing
-#from collections import OrderedDict
-
 
 import tkinter as tk
 from tkinter.ttk import Style, Frame, Button, Scrollbar, Label, Notebook
 from tkinter.scrolledtext import ScrolledText
 
+# BibleOrgSys imports
+from BibleOrgSys import BibleOrgSysGlobals
+from BibleOrgSys.BibleOrgSysGlobals import vPrint
+from BibleOrgSys.Reference.BibleOrganisationalSystems import BibleOrganisationalSystem
+#from BibleOrgSys.Reference.BibleVersificationSystems import BibleVersificationSystems
+#from BibleOrgSys.Reference.VerseReferences import SimpleVerseKey
+from BibleOrgSys.Reference.BibleStylesheets import BibleStylesheet
+from BibleOrgSys.Formats.SwordResources import SwordType, SwordInterface
+from BibleOrgSys.Online.SwordInstallManager import SwordInstallManager
+
 # Biblelator imports
+if __name__ == '__main__':
+    import sys
+    aboveAboveFolderPath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
+    if aboveAboveFolderPath not in sys.path:
+        sys.path.insert( 0, aboveAboveFolderPath )
 from Biblelator.BiblelatorGlobals import DEFAULT, tkSTART, MAX_PSEUDOVERSES, errorBeep, \
+        DATAFILES_FOLDERPATH, \
         DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME, SETTINGS_SUBFOLDER_NAME, \
         DEFAULT_KEY_BINDING_DICT, \
         parseWindowGeometry, assembleWindowGeometryFromList, centreWindow, \
@@ -70,16 +74,14 @@ from Biblelator.Windows.TextBoxes import BEntry, BCombobox
 from Biblelator.Windows.ChildWindows import ChildWindows
 from Biblelator.Windows.TextEditWindow import TextEditWindow
 
-# BibleOrgSys imports
-from BibleOrgSys import BibleOrgSysGlobals
-from BibleOrgSys.BibleOrgSysGlobals import vPrint
-from BibleOrgSys.Reference.BibleOrganisationalSystems import BibleOrganisationalSystem
-#from BibleOrgSys.Reference.BibleVersificationSystems import BibleVersificationSystems
-#from BibleOrgSys.Reference.VerseReferences import SimpleVerseKey
-from BibleOrgSys.Reference.BibleStylesheets import BibleStylesheet
-from BibleOrgSys.Formats.SwordResources import SwordType, SwordInterface
-from BibleOrgSys.Online.SwordInstallManager import SwordInstallManager
 
+LAST_MODIFIED_DATE = '2020-04-22' # by RJH
+SHORT_PROGRAM_NAME = "SwordManager"
+PROGRAM_NAME = "Sword Manager"
+PROGRAM_VERSION = '0.06' # Separate versioning from Biblelator
+programNameVersion = f'{SHORT_PROGRAM_NAME} v{PROGRAM_VERSION}'
+
+debuggingThisModule = False
 
 
 MAIN_APP_NAME = 'Biblelator'
@@ -103,7 +105,7 @@ class SwordManager( Frame ):
         Creates the main menu and toolbar which includes the main BCV (book/chapter/verse) selector.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("SwordManager.__init__( {}, {}, {}, … )").format( rootWindow, homeFolderPath, loggingFolderPath ) )
+            vPrint( 'Quiet', debuggingThisModule, _("SwordManager.__init__( {}, {}, {}, … )").format( rootWindow, homeFolderPath, loggingFolderPath ) )
         self.rootWindow, self.homeFolderPath, self.loggingFolderPath, self.iconImage, self.settings = rootWindow, homeFolderPath, loggingFolderPath, iconImage, settings
         self.parentApp = self # Yes, that's me, myself!
         self.starting = True
@@ -125,8 +127,8 @@ class SwordManager( Frame ):
         self.lexiconWord = None
         self.currentProject = None
 
-        if BibleOrgSysGlobals.debugFlag: print( "Button default font", Style().lookup('TButton', 'font') )
-        if BibleOrgSysGlobals.debugFlag: print( "Label default font", Style().lookup('TLabel', 'font') )
+        if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Button default font", Style().lookup('TButton', 'font') )
+        if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Label default font", Style().lookup('TLabel', 'font') )
 
         # We rely on the parseAndApplySettings() call below to do this
         ## Set-up our Bible system and our callables
@@ -134,7 +136,7 @@ class SwordManager( Frame ):
         #self.setGenericBibleOrganisationalSystem( self.genericBibleOrganisationalSystemName )
 
         self.stylesheet = BibleStylesheet().loadDefault()
-        Frame.__init__( self, self.rootWindow )
+        super().__init__( self.rootWindow )
         self.pack()
 
         self.rootWindow.protocol( 'WM_DELETE_WINDOW', self.doCloseMe ) # Catch when app is closed
@@ -159,7 +161,7 @@ class SwordManager( Frame ):
             self.debugTextBox.pack( side=tk.BOTTOM, fill=tk.BOTH )
             #self.debugTextBox.tag_configure( 'emp', background='yellow', font='helvetica 12 bold', relief='tk.RAISED' )
             self.debugTextBox.tag_configure( 'emp', font='helvetica 10 bold' )
-            self.setDebugText( "Starting up…" )
+            if debuggingThisModule: self.setDebugText( "Starting up…" )
 
         self.keyBindingDict = DEFAULT_KEY_BINDING_DICT
         self.myKeyboardBindingsList = []
@@ -204,7 +206,7 @@ class SwordManager( Frame ):
             that it contains all the books that we might ever want to navigate to.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("setGenericBibleOrganisationalSystem( {} )").format( BOSname ) )
+            vPrint( 'Quiet', debuggingThisModule, _("setGenericBibleOrganisationalSystem( {} )").format( BOSname ) )
 
         # Set-up our Bible system and our callables
         self.genericBibleOrganisationalSystem = BibleOrganisationalSystem( self.genericBibleOrganisationalSystemName )
@@ -222,17 +224,17 @@ class SwordManager( Frame ):
         #self.getBookList = self.genericBibleOrganisationalSystem.getBookList
 
         # Make a bookNumber table with GEN as #1
-        #print( self.genericBookList )
+        #vPrint( 'Quiet', debuggingThisModule, self.genericBookList )
         self.offsetGenesis = self.genericBookList.index( 'GEN' )
-        #print( 'offsetGenesis', self.offsetGenesis )
+        #vPrint( 'Quiet', debuggingThisModule, 'offsetGenesis', self.offsetGenesis )
         self.bookNumberTable = {}
         for j,BBB in enumerate(self.genericBookList):
             k = j + 1 - self.offsetGenesis
             nBBB = BibleOrgSysGlobals.loadedBibleBooksCodes.getReferenceNumber( BBB )
-            #print( BBB, nBBB )
+            #vPrint( 'Quiet', debuggingThisModule, BBB, nBBB )
             self.bookNumberTable[k] = BBB
             self.bookNumberTable[BBB] = k
-        #print( self.bookNumberTable )
+        #vPrint( 'Quiet', debuggingThisModule, self.bookNumberTable )
     # end of SwordManager.setGenericBibleOrganisationalSystem
 
 
@@ -240,7 +242,7 @@ class SwordManager( Frame ):
         """
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createNormalMenuBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createNormalMenuBar()") )
 
         #self.win = Toplevel( self )
         self.menubar = tk.Menu( self.rootWindow )
@@ -292,7 +294,7 @@ class SwordManager( Frame ):
         """
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createTouchMenuBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createTouchMenuBar()") )
             assert self.touchMode
 
         self.createNormalMenuBar()
@@ -303,7 +305,7 @@ class SwordManager( Frame ):
         """
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createNormalNavigationBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createNormalNavigationBar()") )
 
         return
 
@@ -332,7 +334,7 @@ class SwordManager( Frame ):
         self.bookNumberVar = tk.StringVar()
         self.bookNumberVar.set( '1' )
         self.maxBooks = len( self.genericBookList )
-        #print( "maxChapters", self.maxChaptersThisBook )
+        #vPrint( 'Quiet', debuggingThisModule, "maxChapters", self.maxChaptersThisBook )
         self.bookNumberSpinbox = tk.Spinbox( navigationBar, width=3, from_=1-self.offsetGenesis, to=self.maxBooks, textvariable=self.bookNumberVar )
         #self.bookNumberSpinbox['width'] = 3
         self.bookNumberSpinbox['command'] = self.spinToNewBookNumber
@@ -354,7 +356,7 @@ class SwordManager( Frame ):
         self.chapterNumberVar = tk.StringVar()
         self.chapterNumberVar.set( '1' )
         self.maxChaptersThisBook = self.getNumChapters( BBB )
-        #print( "maxChapters", self.maxChaptersThisBook )
+        #vPrint( 'Quiet', debuggingThisModule, "maxChapters", self.maxChaptersThisBook )
         self.chapterSpinbox = tk.Spinbox( navigationBar, width=3, from_=0.0, to=self.maxChaptersThisBook, textvariable=self.chapterNumberVar )
         #self.chapterSpinbox['width'] = 3
         self.chapterSpinbox['command'] = self.spinToNewChapter
@@ -371,7 +373,7 @@ class SwordManager( Frame ):
         self.verseNumberVar.set( '1' )
         #self.maxVersesThisChapterVar = tk.StringVar()
         self.maxVersesThisChapter = self.getNumVerses( BBB, self.chapterNumberVar.get() )
-        #print( "maxVerses", self.maxVersesThisChapter )
+        #vPrint( 'Quiet', debuggingThisModule, "maxVerses", self.maxVersesThisChapter )
         #self.maxVersesThisChapterVar.set( str(self.maxVersesThisChapter) )
         # Add 1 to maxVerses to enable them to go to the next chapter
         self.verseSpinbox = tk.Spinbox( navigationBar, width=3, from_=0.0, to=1.0+self.maxVersesThisChapter, textvariable=self.verseNumberVar )
@@ -413,7 +415,7 @@ class SwordManager( Frame ):
         """
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createTouchNavigationBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createTouchNavigationBar()") )
             assert self.touchMode
 
         return
@@ -449,7 +451,7 @@ class SwordManager( Frame ):
         self.bookNumberVar = tk.StringVar()
         self.bookNumberVar.set( '1' )
         self.maxBooks = len( self.genericBookList )
-        #print( "maxChapters", self.maxChaptersThisBook )
+        #vPrint( 'Quiet', debuggingThisModule, "maxChapters", self.maxChaptersThisBook )
         self.bookNumberSpinbox = tk.Spinbox( navigationBar, width=3, from_=1-self.offsetGenesis, to=self.maxBooks, textvariable=self.bookNumberVar )
         #self.bookNumberSpinbox['width'] = 3
         self.bookNumberSpinbox['command'] = self.spinToNewBookNumber
@@ -475,7 +477,7 @@ class SwordManager( Frame ):
         self.chapterNumberVar = tk.StringVar()
         self.chapterNumberVar.set( '1' )
         self.maxChaptersThisBook = self.getNumChapters( BBB )
-        #print( "maxChapters", self.maxChaptersThisBook )
+        #vPrint( 'Quiet', debuggingThisModule, "maxChapters", self.maxChaptersThisBook )
         self.chapterSpinbox = tk.Spinbox( navigationBar, width=3, from_=0.0, to=self.maxChaptersThisBook, textvariable=self.chapterNumberVar )
         #self.chapterSpinbox['width'] = 3
         self.chapterSpinbox['command'] = self.spinToNewChapter
@@ -496,7 +498,7 @@ class SwordManager( Frame ):
         self.verseNumberVar.set( '1' )
         #self.maxVersesThisChapterVar = tk.StringVar()
         self.maxVersesThisChapter = self.getNumVerses( BBB, self.chapterNumberVar.get() )
-        #print( "maxVerses", self.maxVersesThisChapter )
+        #vPrint( 'Quiet', debuggingThisModule, "maxVerses", self.maxVersesThisChapter )
         #self.maxVersesThisChapterVar.set( str(self.maxVersesThisChapter) )
         # Add 1 to maxVerses to enable them to go to the next chapter
         self.verseSpinbox = tk.Spinbox( navigationBar, width=3, from_=0.0, to=1.0+self.maxVersesThisChapter, textvariable=self.verseNumberVar )
@@ -542,7 +544,7 @@ class SwordManager( Frame ):
         Create a tool bar containing several helpful buttons at the top of the main window.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createToolBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createToolBar()") )
 
         return
 
@@ -571,14 +573,14 @@ class SwordManager( Frame ):
         """
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createToolBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createToolBar()") )
 
         self.notebook = Notebook( self )
 
         # Adding Frames as pages for the ttk.Notebook
 
         # Sources page
-        print( "Create sources page" )
+        vPrint( 'Quiet', debuggingThisModule, "Create sources page" )
         if self.repoDict is None:
             self.repoDict = {}
             for repoName,repoData in self.SwIM.downloadSources.items():
@@ -618,7 +620,7 @@ class SwordManager( Frame ):
             e2.grid( row=j+1, column=7, sticky=tk.W )
 
         # Folders page
-        print( "Create folders page" )
+        vPrint( 'Quiet', debuggingThisModule, "Create folders page" )
         self.foldersPage = Frame( self.notebook )
         foldersLabel = Label( self.foldersPage, text="Install folder(s)" )
         foldersLabel.grid( row=0, column=0, columnspan=2 )
@@ -646,31 +648,31 @@ class SwordManager( Frame ):
         self.folderTextBox.grid( row=0, column=4, rowspan=3, sticky=tk.N+tk.S+tk.E )
         #for BBB in self.BibleBooksCodesList:
             #self.foldersListbox.insert( tk.END, BBB ) # fill the listbox
-        self.foldersSearch.insert( tk.END, str(self.SwIM.currentInstallFolder) )
+        self.foldersSearch.insert( tk.END, str(self.SwIM.currentInstallFolderpath) )
         self.foldersSearch2.insert( tk.END, str(self.SwIM.currentTempFolder) )
         #self.searchCode( None ) # Go to the above
         #self.foldersSearch.delete( 0, tk.END ) # Clear the search box again
 
 
         # Folders page
-        print( "Create install page" )
+        vPrint( 'Quiet', debuggingThisModule, "Create install page" )
         self.installPage = Frame( self.notebook )
         foldersLabel = Label( self.installPage, text="Install new module(s)" )
         foldersLabel.grid( row=0, column=0, columnspan=2 )
 
         # Folders page
-        print( "Create update page" )
+        vPrint( 'Quiet', debuggingThisModule, "Create update page" )
         self.updatePage = Frame( self.notebook )
         foldersLabel = Label( self.updatePage, text="Update module(s)" )
         foldersLabel.grid( row=0, column=0, columnspan=2 )
 
         # Folders page
-        print( "Create modules page" )
+        vPrint( 'Quiet', debuggingThisModule, "Create modules page" )
         self.modulesPage = Frame( self.notebook )
         foldersLabel = Label( self.modulesPage, text="View modules" )
         foldersLabel.grid( row=0, column=0, columnspan=2 )
 
-        print( "Add all pages" )
+        vPrint( 'Quiet', debuggingThisModule, "Add all pages" )
         self.notebook.add( self.sourcesPage, text=_("Sources") )
         self.notebook.add( self.foldersPage, text=_("Folders") )
         self.notebook.add( self.installPage, text=_("Install new") )
@@ -695,7 +697,7 @@ class SwordManager( Frame ):
         Create a debug tool bar containing several additional buttons at the top of the main window.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createDebugToolBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createDebugToolBar()") )
 
         xPad, yPad = (6, 8) if self.touchMode else (2, 2)
 
@@ -717,7 +719,7 @@ class SwordManager( Frame ):
         Create a status bar containing only one text label at the bottom of the main window.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createStatusBar()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createStatusBar()") )
 
         #Style().configure( 'StatusBar.TLabel', background='pink' )
         #Style().configure( 'StatusBar.TLabel', background='DarkOrange1' )
@@ -737,7 +739,7 @@ class SwordManager( Frame ):
         """
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("createMainKeyboardBindings()") )
+            vPrint( 'Quiet', debuggingThisModule, _("createMainKeyboardBindings()") )
 
         self.myKeyboardBindingsList = []
         for name,command in ( ('Help',self.doHelp),
@@ -746,7 +748,7 @@ class SwordManager( Frame ):
                               ):
             if name in self.keyBindingDict:
                 for keyCode in self.keyBindingDict[name][1:]:
-                    #print( "Bind {} for {}".format( repr(keyCode), repr(name) ) )
+                    #vPrint( 'Quiet', debuggingThisModule, "Bind {} for {}".format( repr(keyCode), repr(name) ) )
                     self.rootWindow.bind( keyCode, command )
                 self.myKeyboardBindingsList.append( (name,self.keyBindingDict[name][0],) )
             else: logging.critical( 'No key binding available for {!r}'.format( name ) )
@@ -766,7 +768,7 @@ class SwordManager( Frame ):
         #Puts most recent first
         #"""
         #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            #print( _("addRecentFile( {} )").format( threeTuple ) )
+            #vPrint( 'Quiet', debuggingThisModule, _("addRecentFile( {} )").format( threeTuple ) )
             #assert len(threeTuple) == 3
 
         #try: self.recentFiles.remove( threeTuple ) # Remove a duplicate if present
@@ -788,9 +790,9 @@ class SwordManager( Frame ):
         Set (or clear) the status bar text.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("setStatus( {!r} )").format( newStatusText ) )
+            vPrint( 'Quiet', debuggingThisModule, _("setStatus( {!r} )").format( newStatusText ) )
 
-        #print( "SB is", repr( self.statusTextVariable.get() ) )
+        #vPrint( 'Quiet', debuggingThisModule, "SB is", repr( self.statusTextVariable.get() ) )
         if newStatusText != self.statusTextVariable.get(): # it's changed
             #self.statusBarTextWidget.configure( state=tk.NORMAL )
             #self.statusBarTextWidget.delete( tkSTART, tk.END )
@@ -808,7 +810,7 @@ class SwordManager( Frame ):
         Set the status bar text and change the cursor to the wait/hourglass cursor.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("setErrorStatus( {!r} )").format( newStatusText ) )
+            vPrint( 'Quiet', debuggingThisModule, _("setErrorStatus( {!r} )").format( newStatusText ) )
 
         #self.rootWindow.configure( cursor='watch' ) # 'wait' can only be used on Windows
         #self.statusTextLabel.configure( style='StatusBar.TLabelWait' )
@@ -822,7 +824,7 @@ class SwordManager( Frame ):
         Set the status bar text and change the cursor to the wait/hourglass cursor.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("setWaitStatus( {!r} )").format( newStatusText ) )
+            vPrint( 'Quiet', debuggingThisModule, _("setWaitStatus( {!r} )").format( newStatusText ) )
 
         self.rootWindow.configure( cursor='watch' ) # 'wait' can only be used on Windows
         #self.statusTextLabel.configure( style='StatusBar.TLabelWait' )
@@ -851,7 +853,7 @@ class SwordManager( Frame ):
         """
         """
         if debuggingThisModule:
-            #print( _("setDebugText( {!r} )").format( newMessage ) )
+            #vPrint( 'Quiet', debuggingThisModule, _("setDebugText( {!r} )").format( newMessage ) )
             assert BibleOrgSysGlobals.debugFlag
 
         logging.info( 'Debug: ' + newMessage ) # Not sure why logging.debug isn't going into the file! XXXXXXXXXXXXX
@@ -889,9 +891,9 @@ class SwordManager( Frame ):
         Set the window theme to the given scheme.
         """
         if BibleOrgSysGlobals.debugFlag:
-            print( _("doChangeTheme( {!r} )").format( newThemeName ) )
+            vPrint( 'Quiet', debuggingThisModule, _("doChangeTheme( {!r} )").format( newThemeName ) )
             assert newThemeName
-            self.setDebugText( 'Set theme to {!r}'.format( newThemeName ) )
+            if debuggingThisModule: self.setDebugText( 'Set theme to {!r}'.format( newThemeName ) )
 
         self.themeName = newThemeName
         try:
@@ -905,9 +907,8 @@ class SwordManager( Frame ):
         """
         """
         enteredText = self.foldersSearch.get()
-        if BibleOrgSysGlobals.debugFlag:
-            if debuggingThisModule: print( _("searchFolder( {}, {!r} )").format( event, enteredText ) )
-            self.setDebugText( "searchFolder…" )
+        vPrint( 'Never', debuggingThisModule, _("searchFolder( {}, {!r} )").format( event, enteredText ) )
+        if debuggingThisModule: self.setDebugText( "searchFolder…" )
 
         if not enteredText: return
 
@@ -933,12 +934,11 @@ class SwordManager( Frame ):
     def gotoNewCode( self, event=None ):
         """
         """
-        if BibleOrgSysGlobals.debugFlag:
-            if debuggingThisModule: print( _("gotoNewCode( {} )").format( event ) )
-            self.setDebugText( "gotoNewCode…" )
-            #print( 'You selected items: %s'%[self.codesListbox.get(int(i)) for i in self.codesListbox.curselection()] )
+        vPrint( 'Never', debuggingThisModule, _("gotoNewCode( {} )").format( event ) )
+        if debuggingThisModule: self.setDebugText( "gotoNewCode…" )
+        #vPrint( 'Quiet', debuggingThisModule, 'You selected items: %s'%[self.codesListbox.get(int(i)) for i in self.codesListbox.curselection()] )
 
-        print( "code cursel", repr(self.codesListbox.curselection()) )
+        vPrint( 'Quiet', debuggingThisModule, "code cursel", repr(self.codesListbox.curselection()) )
         index = int( self.codesListbox.curselection()[0] ) # Top one selected
         self.BBB = self.codesListbox.get( index )
         codeDict =  BibleOrgSysGlobals.loadedBibleBooksCodes._getFullEntry( self.BBB )
@@ -960,7 +960,7 @@ class SwordManager( Frame ):
         """
         viewSettings( self )
         #if BibleOrgSysGlobals.debugFlag:
-            #if debuggingThisModule: print( _("doViewSettings()") )
+            #vPrint( 'Never', debuggingThisModule, _("doViewSettings()") )
             #self.setDebugText( "doViewSettings…" )
         #tEW = TextEditWindow( self )
         ##if windowGeometry: tEW.geometry( windowGeometry )
@@ -980,9 +980,8 @@ class SwordManager( Frame ):
         """
         Open a pop-up text window with the current log displayed.
         """
-        if BibleOrgSysGlobals.debugFlag:
-            if debuggingThisModule: print( _("doViewLog()") )
-            self.setDebugText( "doViewLog…" )
+        vPrint( 'Never', debuggingThisModule, _("doViewLog()") )
+        if debuggingThisModule: self.setDebugText( "doViewLog…" )
 
         self.setWaitStatus( _("doViewLog…") )
         filename = PROGRAM_NAME.replace('/','-').replace(':','_').replace('\\','_') + '_log.txt'
@@ -1005,7 +1004,7 @@ class SwordManager( Frame ):
         Pop-up dialog giving goto/reference info.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("SwordManager.doGotoInfo( {} )").format( event ) )
+            vPrint( 'Quiet', debuggingThisModule, _("SwordManager.doGotoInfo( {} )").format( event ) )
 
         infoString = 'Current location:\n' \
                  + '\nBible Organisational System (BOS):\n' \
@@ -1030,8 +1029,8 @@ class SwordManager( Frame ):
         """
         Display a help box.
         """
-        if BibleOrgSysGlobals.debugFlag and debuggingThisModule: print( _("doHelp()") )
-        from Help import HelpBox
+        if BibleOrgSysGlobals.debugFlag and debuggingThisModule: vPrint( 'Quiet', debuggingThisModule, _("doHelp()") )
+        from Biblelator.Dialogs.Help import HelpBox
 
         helpInfo = programNameVersion
         helpInfo += "\n\nBasic instructions:"
@@ -1055,13 +1054,13 @@ class SwordManager( Frame ):
             collect other useful settings, etc.,
             and then send it all somewhere.
         """
-        if BibleOrgSysGlobals.debugFlag and debuggingThisModule: print( _("doSubmitBug()") )
+        if BibleOrgSysGlobals.debugFlag and debuggingThisModule: vPrint( 'Quiet', debuggingThisModule, _("doSubmitBug()") )
 
         if not self.internetAccessEnabled: # we need to warn
             showError( self, SHORT_PROGRAM_NAME, 'You need to allow Internet access first!' )
             return
 
-        from About import AboutBox
+        from Biblelator.Dialogs.About import AboutBox
 
         submitInfo = programNameVersion
         submitInfo += "\n  This program is not yet finished but we'll add this eventually!"
@@ -1074,8 +1073,8 @@ class SwordManager( Frame ):
         Display an about box.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("doAbout()") )
-        from About import AboutBox
+            vPrint( 'Quiet', debuggingThisModule, _("doAbout()") )
+        from Biblelator.Dialogs.About import AboutBox
 
         aboutInfo = programNameVersion
         aboutInfo += "\nA display manager for Sword (from CrossWire) Bible modules." \
@@ -1090,7 +1089,7 @@ class SwordManager( Frame ):
     #def doProjectClose( self ):
         #"""
         #"""
-        #if BibleOrgSysGlobals.debugFlag and debuggingThisModule: print( _("doProjectClose()") )
+        #if BibleOrgSysGlobals.debugFlag and debuggingThisModule: vPrint( 'Quiet', debuggingThisModule, _("doProjectClose()") )
         #self.notWrittenYet()
     ## end of SwordManager.doProjectClose
 
@@ -1108,10 +1107,10 @@ class SwordManager( Frame ):
         Save files first, and then close child windows.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("SwordManager.doCloseMyChildWindows()") )
+            vPrint( 'Quiet', debuggingThisModule, _("SwordManager.doCloseMyChildWindows()") )
 
         # Try to close edit windows first coz they might have work to save
-        for appWin in self.childWindows[:]:
+        for appWin in self.childWindows.copy():
             if 'Editor' in appWin.genericWindowType and appWin.modified():
                 appWin.doClose()
                 #appWin.onCloseEditor( terminate=False )
@@ -1129,7 +1128,7 @@ class SwordManager( Frame ):
             return False
 
         # Should be able to close all apps now
-        for appWin in self.childWindows[:]:
+        for appWin in self.childWindows.copy():
             appWin.doClose()
         return True
     # end of SwordManager.doCloseMyChildWindows
@@ -1140,9 +1139,9 @@ class SwordManager( Frame ):
         Save files first, and then end the application.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( _("SwordManager.doCloseMe()") )
+            vPrint( 'Quiet', debuggingThisModule, _("SwordManager.doCloseMe()") )
         elif BibleOrgSysGlobals.verbosityLevel > 0:
-            print( _("{} is closing down…").format( SHORT_PROGRAM_NAME ) )
+            vPrint( 'Quiet', debuggingThisModule, _("{} is closing down…").format( SHORT_PROGRAM_NAME ) )
 
         #writeSettingsFile( self )
         if self.doCloseMyChildWindows():
@@ -1159,7 +1158,7 @@ def openSwordManager( parent ):
     This is used when the Sword Manager is used inside another program.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( _("SwordManager.openSwordManager( {} )").format( parent ) )
+        vPrint( 'Quiet', debuggingThisModule, _("SwordManager.openSwordManager( {} )").format( parent ) )
 
     myWin = tk.Toplevel( parent )
     application = SwordManager( myWin, parent.homeFolderPath, parent.loggingFolderPath, parent.iconImage, parent.settings )
@@ -1167,7 +1166,7 @@ def openSwordManager( parent ):
 
 
 
-def demo() -> None:
+def briefDemo() -> None:
     """
     Unattended demo program to handle command line parameters and then run what they want.
 
@@ -1177,11 +1176,11 @@ def demo() -> None:
 
     tkRootWindow = tk.Tk()
     if BibleOrgSysGlobals.debugFlag:
-        print( 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
+        vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
     tkRootWindow.title( programNameVersion )
 
     # Set the window icon and title
-    iconImage = tk.PhotoImage( file='Biblelator.gif' )
+    iconImage = tk.PhotoImage( file=DATAFILES_FOLDERPATH.joinpath( 'Biblelator.gif' ) )
     tkRootWindow.tk.call( 'wm', 'iconphoto', tkRootWindow._w, iconImage )
     tkRootWindow.title( programNameVersion + ' ' + _('starting') + '…' )
 
@@ -1196,46 +1195,80 @@ def demo() -> None:
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
 
     # Program a shutdown
-    tkRootWindow.after( 30000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
+    tkRootWindow.after( 2_000, tkRootWindow.destroy ) # Destroy the widget after 2 seconds
 
     # Start the program running
     tkRootWindow.mainloop()
-# end of SwordManager.demo
+# end of SwordManager.briefdemo
 
+def fullDemo() -> None:
+    """
+    Unattended demo program to handle command line parameters and then run what they want.
 
-def main( homeFolderPath, loggingFolderPath ):
+    Which windows open depends on the saved settings from the last use.
+    """
+    BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
+
+    tkRootWindow = tk.Tk()
+    if BibleOrgSysGlobals.debugFlag:
+        vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
+    tkRootWindow.title( programNameVersion )
+
+    # Set the window icon and title
+    iconImage = tk.PhotoImage( file=DATAFILES_FOLDERPATH.joinpath( 'Biblelator.gif' ) )
+    tkRootWindow.tk.call( 'wm', 'iconphoto', tkRootWindow._w, iconImage )
+    tkRootWindow.title( programNameVersion + ' ' + _('starting') + '…' )
+
+    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
+    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    settings = ApplicationSettings( homeFolderPath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
+    settings.load()
+
+    application = SwordManager( tkRootWindow, homeFolderPath, loggingFolderPath, iconImage, settings )
+    # Calls to the window manager class (wm in Tk)
+    #application.master.title( programNameVersion )
+    #application.master.minsize( application.minimumXSize, application.minimumYSize )
+
+    # Program a shutdown
+    tkRootWindow.after( 30_000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
+
+    # Start the program running
+    tkRootWindow.mainloop()
+# end of SwordManager.fulldemo
+
+def main( homeFolderPath, loggingFolderPath ) -> None:
     """
     Main program to handle command line parameters and then run what they want.
     """
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
 
-    #print( 'FP main', repr(homeFolderPath), repr(loggingFolderPath) )
+    #vPrint( 'Quiet', debuggingThisModule, 'FP main', repr(homeFolderPath), repr(loggingFolderPath) )
 
     numInstancesFound = 0
     if sys.platform == 'linux':
         myProcess = subprocess.Popen( ['ps','xa'], stdout=subprocess.PIPE, stderr=subprocess.PIPE )
         programOutputBytes, programErrorOutputBytes = myProcess.communicate()
-        #print( 'pob', programOutputBytes, programErrorOutputBytes )
+        #vPrint( 'Quiet', debuggingThisModule, 'pob', programOutputBytes, programErrorOutputBytes )
         #returnCode = myProcess.returncode
         programOutputString = programOutputBytes.decode( encoding='utf-8', errors='replace' ) if programOutputBytes else None
         programErrorOutputString = programErrorOutputBytes.decode( encoding='utf-8', errors='replace' ) if programErrorOutputBytes else None
-        #print( 'processes', repr(programOutputString) )
+        #vPrint( 'Quiet', debuggingThisModule, 'processes', repr(programOutputString) )
         for line in programOutputString.split( '\n' ):
             if 'python' in line and PROGRAM_NAME+'.py' in line:
-                if BibleOrgSysGlobals.debugFlag: print( 'Found in ps xa:', repr(line) )
+                if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, 'Found in ps xa:', repr(line) )
                 numInstancesFound += 1
         if programErrorOutputString: logging.critical( "ps xa got error: {}".format( programErrorOutputString ) )
     elif sys.platform in ( 'win32', 'win64', ):
         myProcess = subprocess.Popen( ['tasklist.exe'], stdout=subprocess.PIPE, stderr=subprocess.PIPE )
         programOutputBytes, programErrorOutputBytes = myProcess.communicate()
-        #print( 'pob', programOutputBytes, programErrorOutputBytes )
+        #vPrint( 'Quiet', debuggingThisModule, 'pob', programOutputBytes, programErrorOutputBytes )
         #returnCode = myProcess.returncode
         programOutputString = programOutputBytes.decode( encoding='utf-8', errors='replace' ) if programOutputBytes else None
         programErrorOutputString = programErrorOutputBytes.decode( encoding='utf-8', errors='replace' ) if programErrorOutputBytes else None
-        #print( 'processes', repr(programOutputString) )
+        #vPrint( 'Quiet', debuggingThisModule, 'processes', repr(programOutputString) )
         for line in programOutputString.split( '\n' ):
             if PROGRAM_NAME+'.py' in line:
-                if BibleOrgSysGlobals.debugFlag: print( 'Found in tasklist:', repr(line) )
+                if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, 'Found in tasklist:', repr(line) )
                 numInstancesFound += 1
         if programErrorOutputString: logging.critical( "tasklist got error: {}".format( programErrorOutputString ) )
     else: logging.critical( "Don't know how to check for already running instances in {}/{}.".format( sys.platform, os.name ) )
@@ -1249,10 +1282,10 @@ def main( homeFolderPath, loggingFolderPath ):
 
     tkRootWindow = tk.Tk()
     if BibleOrgSysGlobals.debugFlag:
-        print( 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) ) # e.g., 'x11'
+        vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) ) # e.g., 'x11'
 
     # Set the window icon and title
-    iconImage = tk.PhotoImage( file='Biblelator.gif' )
+    iconImage = tk.PhotoImage( file=DATAFILES_FOLDERPATH.joinpath( 'Biblelator.gif' ) )
     tkRootWindow.tk.call( 'wm', 'iconphoto', tkRootWindow._w, iconImage )
     tkRootWindow.title( programNameVersion + ' ' + _('starting') + '…' )
     application = SwordManager( tkRootWindow, homeFolderPath, loggingFolderPath, iconImage, None )
@@ -1264,26 +1297,32 @@ def main( homeFolderPath, loggingFolderPath ):
     tkRootWindow.mainloop()
 # end of SwordManager.main
 
-
-if __name__ == '__main__':
+def run() -> None:
+    """
+    """
     multiprocessing.freeze_support() # Multiprocessing support for frozen Windows executables
 
     # Configure basic set-up
     homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
-    if homeFolderPath[-1] not in '/\\': homeFolderPath += '/'
-    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    # if homeFolderPath[-1] not in '/\\': homeFolderPath += '/'
+    # loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    loggingFolderPath = homeFolderPath.joinpath( DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
     parser = BibleOrgSysGlobals.setup( SHORT_PROGRAM_NAME, PROGRAM_VERSION, loggingFolderPath=loggingFolderPath )
     parser.add_argument( '-o', '--override', type=str, metavar='INIFilename', dest='override', help="override use of Biblelator.ini set-up" )
     BibleOrgSysGlobals.addStandardOptionsAndProcess( parser )
-    #print( BibleOrgSysGlobals.commandLineArguments ); halt
+    #vPrint( 'Quiet', debuggingThisModule, BibleOrgSysGlobals.commandLineArguments ); halt
 
     if BibleOrgSysGlobals.debugFlag:
-        print( _("Platform is"), sys.platform ) # e.g., 'linux,'win32'
-        print( _("OS name is"), os.name ) # e.g., 'posix','nt'
-        if sys.platform == "linux": print( _("OS uname is"), os.uname() ) # gives about five fields
-        print( _("Running main…") )
+        vPrint( 'Quiet', debuggingThisModule, _("Platform is"), sys.platform ) # e.g., 'linux,'win32'
+        vPrint( 'Quiet', debuggingThisModule, _("OS name is"), os.name ) # e.g., 'posix','nt'
+        if sys.platform == "linux": vPrint( 'Quiet', debuggingThisModule, _("OS uname is"), os.uname() ) # gives about five fields
+        vPrint( 'Quiet', debuggingThisModule, _("Running main…") )
 
     main( homeFolderPath, loggingFolderPath )
 
     BibleOrgSysGlobals.closedown( PROGRAM_NAME, PROGRAM_VERSION )
+# end of SwordManager.run
+
+if __name__ == '__main__':
+    run()
 # end of SwordManager.py
