@@ -34,25 +34,24 @@ Program to allow editing of USFM Bibles using Python3 and Tkinter.
     viewSettings( self )
     writeSettingsFile( self )
     doSendUsageStatistics( self )
-    demo()
+    fullDemo()
 """
-
 from gettext import gettext as _
-
-LAST_MODIFIED_DATE = '2020-04-11' # by RJH
-SHORT_PROGRAM_NAME = "BiblelatorSettingsFunctions"
-PROGRAM_NAME = "Biblelator Settings Functions"
-PROGRAM_VERSION = '0.46'
-SettingsVersion = '0.45' # Only need to change this if the settings format has changed
-programNameVersion = f'{SHORT_PROGRAM_NAME} v{PROGRAM_VERSION}'
-
-debuggingThisModule = False
-
-
 import os
 import logging
 
+# BibleOrgSys imports
+from BibleOrgSys import BibleOrgSysGlobals
+from BibleOrgSys.BibleOrgSysGlobals import vPrint
+from BibleOrgSys.Reference.VerseReferences import SimpleVerseKey
+from BibleOrgSys.Formats.PickledBible import ZIPPED_PICKLE_FILENAME_END
+
 # Biblelator imports
+if __name__ == '__main__':
+    import sys
+    aboveAboveFolderPath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
+    if aboveAboveFolderPath not in sys.path:
+        sys.path.insert( 0, aboveAboveFolderPath )
 from Biblelator.BiblelatorGlobals import APP_NAME, DEFAULT, \
     DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME, SETTINGS_SUBFOLDER_NAME, \
     MINIMUM_MAIN_SIZE, MAXIMUM_MAIN_SIZE, MAX_WINDOWS, MAX_RECENT_FILES, \
@@ -62,11 +61,15 @@ from Biblelator.Dialogs.BiblelatorSimpleDialogs import showError
 from Biblelator.Dialogs.BiblelatorDialogs import SaveWindowsLayoutNameDialog, DeleteWindowsLayoutNameDialog
 from Biblelator.Windows.TextEditWindow import TextEditWindow
 
-# BibleOrgSys imports
-from BibleOrgSys import BibleOrgSysGlobals
-from BibleOrgSys.BibleOrgSysGlobals import vPrint
-from BibleOrgSys.Reference.VerseReferences import SimpleVerseKey
-from BibleOrgSys.Formats.PickledBible import ZIPPED_PICKLE_FILENAME_END
+
+LAST_MODIFIED_DATE = '2020-04-26' # by RJH
+SHORT_PROGRAM_NAME = "BiblelatorSettingsFunctions"
+PROGRAM_NAME = "Biblelator Settings Functions"
+PROGRAM_VERSION = '0.46'
+SettingsVersion = '0.45' # Only need to change this if the settings format has changed
+programNameVersion = f'{SHORT_PROGRAM_NAME} v{PROGRAM_VERSION}'
+
+debuggingThisModule = False
 
 
 
@@ -91,7 +94,7 @@ def convertToPython( text ):
 
 
 
-def parseAndApplySettings( self ):
+def parseAndApplySettings( self ) -> None:
     """
     Parse the settings out of the .INI file.
 
@@ -99,10 +102,10 @@ def parseAndApplySettings( self ):
     """
     logging.info( "parseAndApplySettings()" )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "parseAndApplySettings()" )
+        vPrint( 'Quiet', debuggingThisModule, "parseAndApplySettings()" )
         if BibleOrgSysGlobals.debugFlag: self.setDebugText( "parseAndApplySettings…" )
 
-    def retrieveWindowsSettings( self, windowsSettingsName ):
+    def retrieveWindowsSettings( self, windowsSettingsName:str ):
         """
         Gets a certain windows settings from the settings (INI) file information
             and puts it into a dictionary.
@@ -112,8 +115,8 @@ def parseAndApplySettings( self ):
         Called from parseAndApplySettings().
         """
         if BibleOrgSysGlobals.debugFlag:
-            print( "retrieveWindowsSettings( {} )".format( repr(windowsSettingsName) ) )
-            self.setDebugText( "retrieveWindowsSettings…" )
+            vPrint( 'Quiet', debuggingThisModule, "retrieveWindowsSettings( {} )".format( repr(windowsSettingsName) ) )
+            if debuggingThisModule: self.setDebugText( "retrieveWindowsSettings…" )
         windowsSettingsFields = self.settings.data['WindowSetting'+windowsSettingsName]
         resultDict = {}
         for j in range( 1, MAX_WINDOWS+1 ):
@@ -122,7 +125,7 @@ def parseAndApplySettings( self ):
                 if keyName.startswith( winNumber ):
                     if winNumber not in resultDict: resultDict[winNumber] = {}
                     resultDict[winNumber][keyName[len(winNumber):]] = windowsSettingsFields[keyName]
-        #print( "retrieveWindowsSettings", resultDict )
+        #vPrint( 'Quiet', debuggingThisModule, "retrieveWindowsSettings", resultDict )
         return resultDict
     # end of retrieveWindowsSettings
 
@@ -130,13 +133,13 @@ def parseAndApplySettings( self ):
     # Main code for parseAndApplySettings()
     # Parse main app stuff
     #try: self.rootWindow.geometry( self.settings.data[APP_NAME]['windowGeometry'] )
-    #except KeyError: print( "KeyError1" ) # we had no geometry set
+    #except KeyError: vPrint( 'Quiet', debuggingThisModule, "KeyError1" ) # we had no geometry set
     #except tk.TclError: logging.critical( "Application.__init__: Bad window geometry in settings file: {}".format( settings.data[APP_NAME]['windowGeometry'] ) )
     try:
         windowSize = self.settings.data[APP_NAME]['windowSize'] if 'windowSize' in self.settings.data[APP_NAME] else None
         windowPosition = self.settings.data[APP_NAME]['windowPosition'] if 'windowPosition' in self.settings.data[APP_NAME] else None
         if 0 and debuggingThisModule:
-            print( "main window settings (across/down from ini file) size", repr(windowSize), "pos", repr(windowPosition) )
+            vPrint( 'Quiet', debuggingThisModule, "main window settings (across/down from ini file) size", repr(windowSize), "pos", repr(windowPosition) )
         if windowSize and windowPosition:
             self.update() # Make sure that the window has finished being created
             self.rootWindow.geometry( windowSize + '+' + windowPosition )
@@ -150,7 +153,7 @@ def parseAndApplySettings( self ):
     except KeyError: self.maximumSize = MAXIMUM_MAIN_SIZE
     self.rootWindow.maxsize( *parseWindowSize( self.maximumSize ) )
     if 0 and debuggingThisModule:
-        print( "  apply min", repr(self.minimumSize), repr(parseWindowSize(self.minimumSize)), "max", repr(self.maximumSize), repr(parseWindowSize(self.maximumSize)) )
+        vPrint( 'Quiet', debuggingThisModule, "  apply min", repr(self.minimumSize), repr(parseWindowSize(self.minimumSize)), "max", repr(self.maximumSize), repr(parseWindowSize(self.maximumSize)) )
 
     try: self.doChangeTheme( self.settings.data[APP_NAME]['themeName'] )
     except KeyError: logging.warning( "Settings.KeyError: no themeName" )
@@ -232,25 +235,28 @@ def parseAndApplySettings( self ):
     try: self.lastFileDir = self.settings.data['Paths']['lastFileDir']
     except KeyError: pass # use program default
     finally:
-        if self.lastFileDir[-1] not in '/\\': self.lastFileDir += '/'
+        if str(self.lastFileDir)[-1] not in '/\\':
+            self.lastFileDir = f'{self.lastFileDir}/'
     try: self.lastBiblelatorFileDir = self.settings.data['Paths']['lastBiblelatorFileDir']
     except KeyError: pass # use program default
     finally:
-        if self.lastBiblelatorFileDir[-1] not in '/\\': self.lastBiblelatorFileDir += '/'
+        if str(self.lastBiblelatorFileDir)[-1] not in '/\\':
+            self.lastBiblelatorFileDir = f'{self.lastBiblelatorFileDir}/'
     try: self.lastParatextFileDir = self.settings.data['Paths']['lastParatextFileDir']
     except KeyError: pass # use program default
     finally:
-        if isinstance( self.lastParatextFileDir, str) and self.lastParatextFileDir[-1] not in '/\\':
-            self.lastParatextFileDir += '/'
+        if str(self.lastParatextFileDir)[-1] not in '/\\':
+            self.lastParatextFileDir = f'{self.lastParatextFileDir}/'
     try: self.lastInternalBibleDir = self.settings.data['Paths']['lastInternalBibleDir']
     except KeyError: pass # use program default
     finally:
-        if isinstance( self.lastInternalBibleDir, str) and self.lastInternalBibleDir[-1] not in '/\\':
-            self.lastInternalBibleDir += '/'
+        if str(self.lastInternalBibleDir)[-1] not in '/\\':
+            self.lastInternalBibleDir = f'{self.lastInternalBibleDir}/'
     try: self.lastSwordDir = self.settings.data['Paths']['lastSwordDir']
     except KeyError: pass # use program default
     finally:
-        if self.lastSwordDir[-1] not in '/\\': self.lastSwordDir += '/'
+        if str(self.lastSwordDir)[-1] not in '/\\':
+            self.lastSwordDir = f'{self.lastSwordDir}/'
 
     # Parse recent files
     assert not self.recentFiles
@@ -258,14 +264,15 @@ def parseAndApplySettings( self ):
     except KeyError: recentFields = None
     if recentFields: # in settings file
         for j in range( 1, MAX_RECENT_FILES+1 ):
-            recentName = 'recent{}'.format( j )
+            recentName = f'recent{j}'
             for keyName in recentFields:
                 if keyName.startswith( recentName ): # This index number (j) is present
                     filename = convertToPython( self.settings.data['RecentFiles']['recent{}Filename'.format( j )] )
                     #if filename == 'None': filename = None
                     folder = convertToPython( self.settings.data['RecentFiles']['recent{}Folder'.format( j )] )
                     #if folder == 'None': folder = None
-                    if folder and folder[-1] not in '/\\': folder += '/'
+                    if folder and str(folder)[-1] not in '/\\':
+                        folder = f'{folder}/'
                     windowType = self.settings.data['RecentFiles']['recent{}Type'.format( j )]
                     self.recentFiles.append( (filename,folder,windowType) )
                     assert len(self.recentFiles) == j
@@ -298,7 +305,7 @@ def parseAndApplySettings( self ):
     windowsSettingsNamesList = []
     for name in self.settings.data:
         if name.startswith( 'WindowSetting' ): windowsSettingsNamesList.append( name[13:] )
-    if BibleOrgSysGlobals.debugFlag: print( "Available windows settings are: {}".format( windowsSettingsNamesList ) )
+    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Available windows settings are: {}".format( windowsSettingsNamesList ) )
     if windowsSettingsNamesList: assert 'Current' in windowsSettingsNamesList
     self.windowsSettingsDict = {}
     for windowsSettingsName in windowsSettingsNamesList:
@@ -319,7 +326,7 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
     """
     logging.debug( "applyGivenWindowsSettings( {} )".format( repr(givenWindowsSettingsName) ) )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "applyGivenWindowsSettings( {} )".format( repr(givenWindowsSettingsName) ) )
+        vPrint( 'Quiet', debuggingThisModule, "applyGivenWindowsSettings( {} )".format( repr(givenWindowsSettingsName) ) )
         if BibleOrgSysGlobals.debugFlag: self.setDebugText( "applyGivenWindowsSettings…" )
 
     self.doCloseMyChildWindows()
@@ -334,7 +341,7 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
             windowSize = thisStuff['Size'] if 'Size' in thisStuff else None
             windowPosition = thisStuff['Position'] if 'Position' in thisStuff else None
             windowGeometry = windowSize+'+'+windowPosition if windowSize and windowPosition else None
-            #print( "applyGivenWindowsSettings", windowType, windowGeometry )
+            #vPrint( 'Quiet', debuggingThisModule, "applyGivenWindowsSettings", windowType, windowGeometry )
 
             if windowType == 'SwordBibleResourceWindow':
                 rw = self.openSwordBibleResourceWindow( thisStuff['ModuleAbbreviation'], windowGeometry )
@@ -343,18 +350,18 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                 rw = self.openDBPBibleResourceWindow( thisStuff['ModuleAbbreviation'], windowGeometry )
                 #except: logging.critical( "Unable to read all DBPBibleResourceWindow {} settings".format( j ) )
             elif windowType == 'InternalBibleResourceWindow':
-                folderPath = thisStuff['BibleFolderPath']
-                if folderPath[-1] not in '/\\' \
-                and not str(folderPath).endswith( ZIPPED_PICKLE_FILENAME_END ):
-                    folderPath += '/'
-                rw = self.openInternalBibleResourceWindow( folderPath, windowGeometry )
+                folderpath = thisStuff['BibleFolderPath']
+                if folderpath[-1] not in '/\\' \
+                and not str(folderpath).endswith( ZIPPED_PICKLE_FILENAME_END ):
+                    folderpath = f'{folderpath}/'
+                rw = self.openInternalBibleResourceWindow( folderpath, windowGeometry )
                 #except: logging.critical( "Unable to read all InternalBibleResourceWindow {} settings".format( j ) )
             elif windowType == 'HebrewBibleResourceWindow':
-                folderPath = thisStuff['BibleFolderPath']
-                if folderPath[-1] not in '/\\' \
-                and not str(folderPath).endswith( ZIPPED_PICKLE_FILENAME_END ):
-                    folderPath += '/'
-                rw = self.openHebrewBibleResourceWindow( folderPath, windowGeometry )
+                folderpath = thisStuff['BibleFolderPath']
+                if folderpath[-1] not in '/\\' \
+                and not str(folderpath).endswith( ZIPPED_PICKLE_FILENAME_END ):
+                    folderpath = f'{folderpath}/'
+                rw = self.openHebrewBibleResourceWindow( folderpath, windowGeometry )
 
             #elif windowType == 'HebrewLexiconResourceWindow':
                 #self.openHebrewLexiconResourceWindow( thisStuff['HebrewLexiconPath'], windowGeometry )
@@ -377,17 +384,22 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                         boxType = boxSource = None
                         for keyname in collectionSettingsFields:
                             if keyname.startswith( boxNumber ):
-                                #print( "found", keyname, "setting for", collectionName, "collection" )
+                                #vPrint( 'Quiet', debuggingThisModule, "found", keyname, "setting for", collectionName, "collection" )
                                 if keyname == boxNumber+'Type': boxType = collectionSettingsFields[keyname]
                                 elif keyname == boxNumber+'Source': boxSource = collectionSettingsFields[keyname]
                                 else:
-                                    print( "Unknown {} collection key: {} = {}".format( repr(collectionName), keyname, collectionSettingsFields[keyname] ) )
+                                    vPrint( 'Quiet', debuggingThisModule, "Unknown {} collection key: {} = {}".format( repr(collectionName), keyname, collectionSettingsFields[keyname] ) )
                                     if BibleOrgSysGlobals.debugFlag: halt
                         if boxType and boxSource:
                             #if boxType in ( 'Internal', ):
                                 #if boxSource[-1] not in '/\\': boxSource += '/' # Are they all folders -- might be wrong
                             rw.openBox( boxType, boxSource )
 
+            elif windowType == 'TSVBibleEditWindow':
+                try: filepath = convertToPython( thisStuff['TSVTablePath'] )
+                except KeyError: filepath = None
+                rw = self.openFileTSVEditWindow( filepath, windowGeometry )
+
             elif windowType == 'BibleReferenceCollectionWindow':
                 xyz = "JustTesting!"
                 rw = self.openBibleReferenceCollectionWindow( xyz, windowGeometry )
@@ -400,9 +412,9 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                 rw = self.openFileTextEditWindow( filepath, windowGeometry )
                 #except: logging.critical( "Unable to read all PlainTextEditWindow {} settings".format( j ) )
             elif windowType == 'BiblelatorUSFMBibleEditWindow':
-                folderPath = thisStuff['ProjectFolderPath']
-                if folderPath[-1] not in '/\\': folderPath += '/'
-                rw = self.openBiblelatorBibleEditWindow( folderPath, thisStuff['EditMode'], windowGeometry )
+                folderpath = thisStuff['ProjectFolderPath']
+                if folderpath[-1] not in '/\\': folderpath = f'{folderpath}/'
+                rw = self.openBiblelatorBibleEditWindow( folderpath, thisStuff['EditMode'], windowGeometry )
                 #except: logging.critical( "Unable to read all BiblelatorUSFMBibleEditWindow {} settings".format( j ) )
             elif windowType == 'Paratext8USFMBibleEditWindow':
                 rw = self.openParatext8BibleEditWindow( thisStuff['ProjectFolder'], thisStuff['EditMode'], windowGeometry )
@@ -412,9 +424,9 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                 rw = self.openParatext7BibleEditWindow( thisStuff['SSFFilepath'], thisStuff['EditMode'], windowGeometry )
                 #except: logging.critical( "Unable to read all Paratext7USFMBibleEditWindow {} settings".format( j ) )
             elif windowType == 'ESFMEditWindow':
-                folderPath = thisStuff['ESFMFolder']
-                if folderPath[-1] not in '/\\': folderPath += '/'
-                rw = self.openESFMEditWindow( folderPath, thisStuff['EditMode'], windowGeometry )
+                folderpath = thisStuff['ESFMFolder']
+                if folderpath[-1] not in '/\\': folderpath = f'{folderpath}/'
+                rw = self.openESFMEditWindow( folderpath, thisStuff['EditMode'], windowGeometry )
                 #except: logging.critical( "Unable to read all ESFMEditWindow {} settings".format( j ) )
 
             else:
@@ -470,7 +482,7 @@ def getCurrentChildWindowSettings( self ):
     """
     logging.debug( "getCurrentChildWindowSettings()" )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "getCurrentChildWindowSettings()" )
+        vPrint( 'Quiet', debuggingThisModule, "getCurrentChildWindowSettings()" )
 
     if 'Current' in self.windowsSettingsDict: del self.windowsSettingsDict['Current']
     self.windowsSettingsDict['Current'] = {}
@@ -483,17 +495,17 @@ def getCurrentChildWindowSettings( self ):
         thisOne = self.windowsSettingsDict['Current'][winNumber]
         thisOne['Type'] = appWin.windowType #.replace( 'Window', 'Window' )
         if 0 and debuggingThisModule:
-            print( "Child", j, appWin.genericWindowType, appWin.windowType )
-            print( "  child geometry", appWin.geometry(), "child winfo_geometry", appWin.winfo_geometry() )
-            #print( "  child winfo x", appWin.winfo_x(), "child winfo rootx", appWin.winfo_rootx() )
-            #print( "  child winfo y", appWin.winfo_y(), "child winforooty", appWin.winfo_rooty() )
-            #print( "  child height", appWin.winfo_height(), "child reqheight", appWin.winfo_reqheight() )
-            #print( "  child width", appWin.winfo_width(), "child reqwidth", appWin.winfo_reqwidth() )
+            vPrint( 'Quiet', debuggingThisModule, "Child", j, appWin.genericWindowType, appWin.windowType )
+            vPrint( 'Quiet', debuggingThisModule, "  child geometry", appWin.geometry(), "child winfo_geometry", appWin.winfo_geometry() )
+            #vPrint( 'Quiet', debuggingThisModule, "  child winfo x", appWin.winfo_x(), "child winfo rootx", appWin.winfo_rootx() )
+            #vPrint( 'Quiet', debuggingThisModule, "  child winfo y", appWin.winfo_y(), "child winforooty", appWin.winfo_rooty() )
+            #vPrint( 'Quiet', debuggingThisModule, "  child height", appWin.winfo_height(), "child reqheight", appWin.winfo_reqheight() )
+            #vPrint( 'Quiet', debuggingThisModule, "  child width", appWin.winfo_width(), "child reqwidth", appWin.winfo_reqwidth() )
         thisOne['Size'], thisOne['Position'] = appWin.geometry().split( '+', 1 )
         if thisOne['Position'] == '0+0': # not sure why this occurs for a new window -- pops up top left
             thisOne['Position'] = appWin.winfo_geometry().split( '+', 1 )[1] # Won't be exact but close
             if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-                print( "Corrected {} window position from '0+0' to {}".format( appWin.windowType, thisOne['Position'] ) )
+                vPrint( 'Quiet', debuggingThisModule, "Corrected {} window position from '0+0' to {}".format( appWin.windowType, thisOne['Position'] ) )
         thisOne['MinimumSize'] = assembleWindowSize( *appWin.minsize() )
         thisOne['MaximumSize'] = assembleWindowSize( *appWin.maxsize() )
         thisOne['StatusBar'] = 'On' if appWin._showStatusBarVar.get() else 'Off'
@@ -507,13 +519,16 @@ def getCurrentChildWindowSettings( self ):
         elif appWin.windowType == 'HebrewBibleResourceWindow':
             thisOne['BibleFolderPath'] = appWin.moduleID
 
+        elif appWin.windowType == 'TSVBibleEditWindow':
+            thisOne['TSVTablePath'] = appWin.filepath
+
         elif appWin.windowType == 'BibleLexiconResourceWindow':
             thisOne['BibleLexiconPath'] = appWin.moduleID
 
         elif appWin.windowType == 'BibleResourceCollectionWindow':
             thisOne['CollectionName'] = appWin.moduleID
         elif appWin.windowType == 'BibleReferenceCollectionWindow':
-            print( "WARNING: Doesn't save BibleReferenceCollectionWindow yet!" )
+            vPrint( 'Quiet', debuggingThisModule, "WARNING: Doesn't save BibleReferenceCollectionWindow yet!" )
             #thisOne['CollectionName'] = appWin.moduleID # Just copied -- not checked
 
         elif appWin.windowType == 'PlainTextEditWindow':
@@ -538,9 +553,13 @@ def getCurrentChildWindowSettings( self ):
             try: thisOne['GroupCode'] = appWin._groupCode
             except AttributeError: logging.critical( "getCurrentChildWindowSettings: " + _("Why no groupCode in {}").format( appWin.windowType ) )
             try: thisOne['ContextViewMode'] = appWin._contextViewMode
-            except AttributeError: logging.critical( "getCurrentChildWindowSettings: " + _("Why no contextViewMode in {}").format( appWin.windowType ) )
+            except AttributeError:
+                if 'TSV' not in appWin.windowType:
+                    logging.critical( "getCurrentChildWindowSettings: " + _("Why no contextViewMode in {}").format( appWin.windowType ) )
             try: thisOne['FormatViewMode'] = appWin._formatViewMode
-            except AttributeError: logging.critical( "getCurrentChildWindowSettings: " + _("Why no formatViewMode in {}").format( appWin.windowType ) )
+            except AttributeError:
+                if 'TSV' not in appWin.windowType:
+                    logging.critical( "getCurrentChildWindowSettings: " + _("Why no formatViewMode in {}").format( appWin.windowType ) )
 
         if appWin.windowType.endswith( 'EditWindow' ):
             thisOne['AutocompleteMode'] = appWin.autocompleteMode
@@ -555,15 +574,15 @@ def saveNewWindowSetup( self ):
     "self" refers to a Biblelator Application instance.
     """
     if BibleOrgSysGlobals.debugFlag:
-        print( "saveNewWindowSetup()" )
-        self.setDebugText( "saveNewWindowSetup…" )
+        vPrint( 'Quiet', debuggingThisModule, "saveNewWindowSetup()" )
+        if debuggingThisModule: self.setDebugText( "saveNewWindowSetup…" )
 
     swnd = SaveWindowsLayoutNameDialog( self, self.windowsSettingsDict, title=_('Save window setup') )
-    if BibleOrgSysGlobals.debugFlag: print( "swndResult", repr(swnd.result) )
+    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "swndResult", repr(swnd.result) )
     if swnd.result:
         getCurrentChildWindowSettings( self )
         self.windowsSettingsDict[swnd.result] = self.windowsSettingsDict['Current'] # swnd.result is the new window name
-        #print( "swS", self.windowsSettingsDict )
+        #vPrint( 'Quiet', debuggingThisModule, "swS", self.windowsSettingsDict )
         writeSettingsFile( self ) # Save file now in case we crash
         self.createMenuBar() # refresh
 # end of saveNewWindowSetup
@@ -577,12 +596,12 @@ def deleteExistingWindowSetup( self ):
     "self" refers to a Biblelator Application instance.
     """
     if BibleOrgSysGlobals.debugFlag:
-        print( "deleteExistingWindowSetup()" )
-        self.setDebugText( "deleteExistingWindowSetup" )
+        vPrint( 'Quiet', debuggingThisModule, "deleteExistingWindowSetup()" )
+        if debuggingThisModule: self.setDebugText( "deleteExistingWindowSetup" )
         assert self.windowsSettingsDict and (len(self.windowsSettingsDict)>1 or 'Current' not in self.windowsSettingsDict)
 
     dwnd = DeleteWindowsLayoutNameDialog( self, self.windowsSettingsDict, title=_('Delete saved window setup') )
-    if BibleOrgSysGlobals.debugFlag: print( "dwndResult", repr(dwnd.result) )
+    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "dwndResult", repr(dwnd.result) )
     if dwnd.result:
         if BibleOrgSysGlobals.debugFlag:
             assert dwnd.result in self.windowsSettingsDict
@@ -600,8 +619,8 @@ def viewSettings( self ):
     "self" refers to a Biblelator Application instance.
     """
     if BibleOrgSysGlobals.debugFlag:
-        print( "viewSettings()" )
-        self.setDebugText( "viewSettings" )
+        vPrint( 'Quiet', debuggingThisModule, "viewSettings()" )
+        if debuggingThisModule: self.setDebugText( "viewSettings" )
 
     tEW = TextEditWindow( self )
     #if windowGeometry: tEW.geometry( windowGeometry )
@@ -625,9 +644,9 @@ def writeSettingsFile( self ):
     """
     logging.info( "writeSettingsFile()" )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "writeSettingsFile()" )
+        vPrint( 'Quiet', debuggingThisModule, "writeSettingsFile()" )
     elif BibleOrgSysGlobals.verbosityLevel > 0:
-        print( _("  Saving program settings…") )
+        vPrint( 'Quiet', debuggingThisModule, _("  Saving program settings…") )
 
     def convertToString( setting ):
         """
@@ -649,16 +668,16 @@ def writeSettingsFile( self ):
     mainStuff['PROGRAM_VERSION'] = PROGRAM_VERSION
     mainStuff['themeName'] = self.themeName
     if 0 and debuggingThisModule:
-        print( " root geometry", self.rootWindow.geometry(), "root winfo_geometry", self.rootWindow.winfo_geometry() )
-        print( " root winfo x", self.rootWindow.winfo_x(), "root winfo rootx", self.rootWindow.winfo_rootx() )
-        print( " root winfo y", self.rootWindow.winfo_y(), "root winfo rooty", self.rootWindow.winfo_rooty() )
+        vPrint( 'Quiet', debuggingThisModule, " root geometry", self.rootWindow.geometry(), "root winfo_geometry", self.rootWindow.winfo_geometry() )
+        vPrint( 'Quiet', debuggingThisModule, " root winfo x", self.rootWindow.winfo_x(), "root winfo rootx", self.rootWindow.winfo_rootx() )
+        vPrint( 'Quiet', debuggingThisModule, " root winfo y", self.rootWindow.winfo_y(), "root winfo rooty", self.rootWindow.winfo_rooty() )
     mainStuff['windowSize'], mainStuff['windowPosition'] = self.rootWindow.geometry().split( '+', 1 )
     # Seems that winfo_geometry doesn't work above (causes root Window to move)
     mainStuff['minimumSize'] = self.minimumSize
     mainStuff['maximumSize'] = self.maximumSize
     if 0 and debuggingThisModule:
-        print( " saved size (across/down) to ini file", repr(mainStuff['windowSize']), "pos", repr(mainStuff['windowPosition']) )
-        print( "   min", repr(mainStuff['minimumSize']), "max", repr(mainStuff['maximumSize']) )
+        vPrint( 'Quiet', debuggingThisModule, " saved size (across/down) to ini file", repr(mainStuff['windowSize']), "pos", repr(mainStuff['windowPosition']) )
+        vPrint( 'Quiet', debuggingThisModule, "   min", repr(mainStuff['minimumSize']), "max", repr(mainStuff['maximumSize']) )
 
     # Save the user interface settings
     self.settings.data['Interface'] = {}
@@ -741,19 +760,19 @@ def writeSettingsFile( self ):
     if self.lexiconWord: lexicon['currentWord'] = self.lexiconWord
 
     # Save any open Bible resource collections
-    if BibleOrgSysGlobals.debugFlag and debuggingThisModule: print( "save collection data…" )
+    if BibleOrgSysGlobals.debugFlag and debuggingThisModule: vPrint( 'Quiet', debuggingThisModule, "save collection data…" )
     for appWin in self.childWindows:
-        #print( "  gT", appWin.genericWindowType )
-        #print( "  wT", appWin.windowType )
+        #vPrint( 'Quiet', debuggingThisModule, "  gT", appWin.genericWindowType )
+        #vPrint( 'Quiet', debuggingThisModule, "  wT", appWin.windowType )
         if appWin.windowType == 'BibleResourceCollectionWindow':
             if appWin.resourceBoxesList: # so we don't create just an empty heading for an empty collection
                 self.settings.data['BibleResourceCollection'+appWin.moduleID] = {}
                 thisOne = self.settings.data['BibleResourceCollection'+appWin.moduleID]
-                #print( "  found", appWin.moduleID )
+                #vPrint( 'Quiet', debuggingThisModule, "  found", appWin.moduleID )
                 for j, box in enumerate( appWin.resourceBoxesList ):
                     boxNumber = 'box{}'.format( j+1 )
-                    #print( "    bT", box.boxType )
-                    #print( "    ID", box.moduleID )
+                    #vPrint( 'Quiet', debuggingThisModule, "    bT", box.boxType )
+                    #vPrint( 'Quiet', debuggingThisModule, "    ID", box.moduleID )
                     thisOne[boxNumber+'Type'] = box.boxType.replace( 'BibleResourceBox', '' )
                     thisOne[boxNumber+'Source'] = box.moduleID
 
@@ -762,12 +781,12 @@ def writeSettingsFile( self ):
     # Save all the various window set-ups including both the named ones and the current one
     for windowsSettingName in sorted( self.windowsSettingsDict ):
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "Saving windows set-up {}".format( repr(windowsSettingName) ) )
+            vPrint( 'Quiet', debuggingThisModule, "Saving windows set-up {}".format( repr(windowsSettingName) ) )
         try: # Just in case something goes wrong with characters in a settings name
             self.settings.data['WindowSetting'+windowsSettingName] = {}
             thisOne = self.settings.data['WindowSetting'+windowsSettingName]
             for windowNumber,winDict in sorted( self.windowsSettingsDict[windowsSettingName].items() ):
-                #print( "  ", repr(windowNumber), repr(winDict) )
+                #vPrint( 'Quiet', debuggingThisModule, "  ", repr(windowNumber), repr(winDict) )
                 for windowSettingName,value in sorted( winDict.items() ):
                     thisOne[windowNumber+windowSettingName] = convertToString( value )
         except UnicodeEncodeError: logging.error( "writeSettingsFile: " + _("unable to write {} windows set-up").format( repr(windowsSettingName) ) )
@@ -786,11 +805,11 @@ def doSendUsageStatistics( self ):
     Note that Biblelator is mostly closed down at this stage.
     """
     if BibleOrgSysGlobals.debugFlag:
-        print( "doSendUsageStatistics()" )
+        vPrint( 'Quiet', debuggingThisModule, "doSendUsageStatistics()" )
         assert self.internetAccessEnabled
         assert self.sendUsageStatisticsEnabled
     elif BibleOrgSysGlobals.verbosityLevel > 0:
-        print( _("  Sending program usage info…") )
+        vPrint( 'Quiet', debuggingThisModule, _("  Sending program usage info…") )
 
     adjAppName = APP_NAME.replace('/','-').replace(':','_').replace('\\','_').replace(' ','_')
     adjUserName = self.currentUserName.replace('/','-').replace(':','_').replace('\\','_')
@@ -798,31 +817,31 @@ def doSendUsageStatistics( self ):
     # Package our stuff up into a zip file
     import tempfile, zipfile
     zipFilepath = os.path.join( tempfile.gettempdir(), adjAppName+'.zip' )
-    #print( "zipF0", repr(zipFilepath) )
+    #vPrint( 'Quiet', debuggingThisModule, "zipF0", repr(zipFilepath) )
     zf = zipfile.ZipFile( zipFilepath, 'w', compression=zipfile.ZIP_DEFLATED )
 
     # Add log file(s)
     filename = adjAppName + '_log.txt'
-    #print( "zipF1", repr(self.loggingFolderPath) )
-    #print( "zipF2", repr(filename) )
+    #vPrint( 'Quiet', debuggingThisModule, "zipF1", repr(self.loggingFolderPath) )
+    #vPrint( 'Quiet', debuggingThisModule, "zipF2", repr(filename) )
     for extension in BibleOrgSysGlobals.STANDARD_BACKUP_EXTENSIONS:
         filepath = os.path.join( self.loggingFolderPath, filename+extension )
-        #print( "  zipF3", repr(filepath) )
+        #vPrint( 'Quiet', debuggingThisModule, "  zipF3", repr(filepath) )
         if os.path.exists( filepath ):
-            #print( "  zipF4", repr(filepath) )
+            #vPrint( 'Quiet', debuggingThisModule, "  zipF4", repr(filepath) )
             zf.write( filepath, filename+extension )
 
     # Add usage file(s)
     zf.write( self.usageLogPath, self.usageFilename )
 
     # Add settings file(s)
-    #print( "zipF5", repr(self.settings.settingsFilepath) )
-    #print( "zipF6", repr(self.settings.settingsFilename) )
+    #vPrint( 'Quiet', debuggingThisModule, "zipF5", repr(self.settings.settingsFilepath) )
+    #vPrint( 'Quiet', debuggingThisModule, "zipF6", repr(self.settings.settingsFilename) )
     for extension in BibleOrgSysGlobals.STANDARD_BACKUP_EXTENSIONS:
         filepath = self.settings.settingsFilepath+extension
-        #print( "  zipF7", repr(filepath) )
+        #vPrint( 'Quiet', debuggingThisModule, "  zipF7", repr(filepath) )
         if os.path.exists( filepath ):
-            #print( "  zipF8", repr(filepath) )
+            #vPrint( 'Quiet', debuggingThisModule, "  zipF8", repr(filepath) )
             zf.write( filepath, self.settings.settingsFilename+extension )
     zf.close()
     with open( zipFilepath, 'rb' ) as zFile:
@@ -843,32 +862,32 @@ def doSendUsageStatistics( self ):
                     'Content-Type: application/zip', '', zDataStr ) )
     parameterList.extend( ('--' + MIME_BOUNDARY + '--' , '') )
     parameterString = '\r\n'.join (parameterList)
-    #print( "\nparameterString", repr(parameterString) )
+    #vPrint( 'Quiet', debuggingThisModule, "\nparameterString", repr(parameterString) )
 
     headers = {"Content-type": "multipart/form-data; MIME_BOUNDARY={}".format( MIME_BOUNDARY ) }
-    #print( "\nheaders", headers )
+    #vPrint( 'Quiet', debuggingThisModule, "\nheaders", headers )
 
     import http.client
     conn = http.client.HTTPConnection( 'Freely-Given.org' )
     conn.request( 'POST', '/Software/Biblelator/StatusInputs/SubmitAction.phtml', parameterString, headers )
     try: response = conn.getresponse()
     except http.client.RemoteDisconnected:
-        print( "doSendUsageStatistics remote RemoteDisconnected -- send failed" )
+        vPrint( 'Quiet', debuggingThisModule, "doSendUsageStatistics remote RemoteDisconnected -- send failed" )
         conn.close()
         return
     if response.status == 200:
-        print( "    doSendUsageStatistics accepted by server" )
+        vPrint( 'Quiet', debuggingThisModule, "    doSendUsageStatistics accepted by server" )
     else:
-        print( "doSendUsageStatistics status", repr(response.status) ) # Should be 200
-        print( "doSendUsageStatistics reason", repr(response.reason) ) # Should be 'OK'
+        vPrint( 'Quiet', debuggingThisModule, "doSendUsageStatistics status", repr(response.status) ) # Should be 200
+        vPrint( 'Quiet', debuggingThisModule, "doSendUsageStatistics reason", repr(response.reason) ) # Should be 'OK'
         data = response.read()
-        print( "doSendUsageStatistics data", repr(data) ) # Web page back from the server
+        vPrint( 'Quiet', debuggingThisModule, "doSendUsageStatistics data", repr(data) ) # Web page back from the server
     conn.close()
 # end of doSendUsageStatistics
 
 
 
-def demo() -> None:
+def briefDemo() -> None:
     """
     Unattended demo program to handle command line parameters and then run what they want.
 
@@ -879,14 +898,14 @@ def demo() -> None:
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
 
     if BibleOrgSysGlobals.debugFlag:
-        print( "Platform is", sys.platform ) # e.g., "win32"
-        print( "OS name is", os.name ) # e.g., "nt"
-        if sys.platform == "linux": print( "OS uname is", os.uname() )
-        print( "Running main…" )
+        vPrint( 'Quiet', debuggingThisModule, "Platform is", sys.platform ) # e.g., "win32"
+        vPrint( 'Quiet', debuggingThisModule, "OS name is", os.name ) # e.g., "nt"
+        if sys.platform == "linux": vPrint( 'Quiet', debuggingThisModule, "OS uname is", os.uname() )
+        vPrint( 'Quiet', debuggingThisModule, "Running main…" )
 
     tkRootWindow = tk.Tk()
     if BibleOrgSysGlobals.debugFlag:
-        print( 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
+        vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
     tkRootWindow.title( programNameVersion )
 
     homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
@@ -900,12 +919,47 @@ def demo() -> None:
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
 
     # Program a shutdown
-    tkRootWindow.after( 30000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
+    tkRootWindow.after( 10_000, tkRootWindow.destroy ) # Destroy the widget after 10 seconds
 
     # Start the program running
     tkRootWindow.mainloop()
-# end of Biblelator.demo
+# end of Biblelator.briefDemo
 
+def fullDemo() -> None:
+    """
+    Full demo to check class is working
+    """
+    import sys, tkinter as tk
+
+    BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
+
+    if BibleOrgSysGlobals.debugFlag:
+        vPrint( 'Quiet', debuggingThisModule, "Platform is", sys.platform ) # e.g., "win32"
+        vPrint( 'Quiet', debuggingThisModule, "OS name is", os.name ) # e.g., "nt"
+        if sys.platform == "linux": vPrint( 'Quiet', debuggingThisModule, "OS uname is", os.uname() )
+        vPrint( 'Quiet', debuggingThisModule, "Running main…" )
+
+    tkRootWindow = tk.Tk()
+    if BibleOrgSysGlobals.debugFlag:
+        vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
+    tkRootWindow.title( programNameVersion )
+
+    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
+    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    settings = ApplicationSettings( homeFolderPath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, APP_NAME )
+    settings.load()
+
+    application = Application( tkRootWindow, homeFolderPath, loggingFolderPath, settings )
+    # Calls to the window manager class (wm in Tk)
+    #application.master.title( programNameVersion )
+    #application.master.minsize( application.minimumXSize, application.minimumYSize )
+
+    # Program a shutdown
+    tkRootWindow.after( 30_000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
+
+    # Start the program running
+    tkRootWindow.mainloop()
+# end of BiblelatorSettingsFunctions.fullDemo
 
 if __name__ == '__main__':
     from multiprocessing import freeze_support
@@ -915,7 +969,7 @@ if __name__ == '__main__':
     parser = BibleOrgSysGlobals.setup( SHORT_PROGRAM_NAME, PROGRAM_VERSION, LAST_MODIFIED_DATE )
     BibleOrgSysGlobals.addStandardOptionsAndProcess( parser )
 
-    demo()
+    fullDemo()
 
     BibleOrgSysGlobals.closedown( PROGRAM_NAME, PROGRAM_VERSION )
 # end of BiblelatorSettingsFunctions.py
